@@ -1,5 +1,6 @@
 import logging
 
+import graph_scheduler
 import pytest
 from psyneulink import _unit_registry
 from psyneulink.core.components.functions.nonstateful.transferfunctions import Linear
@@ -80,6 +81,7 @@ class TestCondition:
         assert not cond.is_satisfied(False, c=False)
         assert not cond.is_satisfied(False, c=False, extra_arg=True)
 
+    @pytest.mark.psyneulink
     class TestGeneric:
         def test_WhileNot_AtPass(self):
             comp = Composition()
@@ -113,6 +115,7 @@ class TestCondition:
             expected_output = [A, A, set(), A, A]
             assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     class TestRelative:
 
         def test_Any_end_before_one_finished(self):
@@ -209,7 +212,8 @@ class TestCondition:
 
             assert output == pytest.helpers.setify_expected_output(expected_output)
 
-    class TestTime:
+    @pytest.mark.psyneulink
+    class TestTimePNL:
 
         def test_BeforeConsiderationSetExecution(self):
             comp = Composition()
@@ -478,6 +482,122 @@ class TestCondition:
             expected_output = [set(), A, A, A, A]
             assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    class TestTime:
+
+        @pytest.mark.parametrize(
+            'node_condition, termination_conditions, expected_output',
+            [
+                pytest.param(
+                    graph_scheduler.AfterNPasses(1),
+                    {
+                        TimeScale.ENVIRONMENT_SEQUENCE: graph_scheduler.AfterNEnvironmentStateUpdates(1),
+                        TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterConsiderationSetExecution(4)
+                    },
+                    [set(), 'A', 'A', 'A', 'A'],
+                    id='AfterConsiderationSetExecution'
+                ),
+                pytest.param(
+                    graph_scheduler.AfterNPasses(1),
+                    {
+                        TimeScale.ENVIRONMENT_SEQUENCE: graph_scheduler.AfterNEnvironmentStateUpdates(1),
+                        TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterNConsiderationSetExecutions(5)
+                    },
+                    [set(), 'A', 'A', 'A', 'A'],
+                    id='AfterNConsiderationSetExecutions'
+                ),
+            ]
+        )
+        def test_single_node(
+            self, node_condition, termination_conditions, expected_output
+        ):
+            graph = {'A': set()}
+
+            sched = graph_scheduler.Scheduler(graph)
+            sched.add_condition('A', node_condition)
+            output = list(sched.run(termination_conds=termination_conditions))
+
+            assert output == pytest.helpers.setify_expected_output(expected_output)
+
+        @pytest.mark.parametrize(
+            'node_condition, termination_conditions, expected_output, n_sequences, n_state_updates_per_sequence',
+            [
+                pytest.param(
+                    graph_scheduler.AtEnvironmentStateUpdateNStart(2),
+                    {TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterNPasses(1)},
+                    [[set(), set(), 'A', set()]],
+                    1,
+                    4,
+                    id='AtEnvironmentStateUpdateNStart'
+                ),
+                pytest.param(
+                    graph_scheduler.AtEnvironmentSequence(4),
+                    {TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterNPasses(1)},
+                    [[set()], [set()], [set()], [set()], ['A'], [set()]],
+                    6,
+                    1,
+                    id='AtEnvironmentSequence'
+                ),
+                pytest.param(
+                    graph_scheduler.AfterEnvironmentSequence(3),
+                    {TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterNPasses(1)},
+                    [[set()], [set()], [set()], [set()], ['A'], ['A']],
+                    6,
+                    1,
+                    id='AfterEnvironmentSequence'
+                ),
+                pytest.param(
+                    graph_scheduler.AfterNEnvironmentSequences(4),
+                    {TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterNPasses(1)},
+                    [[set()], [set()], [set()], [set()], ['A'], ['A']],
+                    6,
+                    1,
+                    id='AfterNEnvironmentSequences'
+                ),
+                pytest.param(
+                    graph_scheduler.AtEnvironmentSequenceStart(),
+                    {TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterNPasses(1)},
+                    [['A', set()], ['A', set()]],
+                    2,
+                    2,
+                    id='AtEnvironmentSequenceStart'
+                ),
+                pytest.param(
+                    graph_scheduler.AtEnvironmentSequenceNStart(1),
+                    {TimeScale.ENVIRONMENT_STATE_UPDATE: graph_scheduler.AfterNPasses(1)},
+                    [[set(), set()], ['A', set()], [set(), set()]],
+                    3,
+                    2,
+                    id='AtEnvironmentSequenceNStart'
+                ),
+            ]
+        )
+        def test_single_node_n_sequences(
+            self,
+            node_condition,
+            termination_conditions,
+            expected_output,
+            n_sequences,
+            n_state_updates_per_sequence
+        ):
+            graph = {'A': set()}
+
+            sched = graph_scheduler.Scheduler(graph)
+            sched.add_condition('A', node_condition)
+            output = []
+
+            for _ in range(n_sequences):
+                su = []
+                for i in range(n_state_updates_per_sequence):
+                    su.extend(
+                        list(sched.run(termination_conds=termination_conditions))
+                    )
+                output.append(su)
+                sched.end_environment_sequence()
+
+            for i in range(n_sequences):
+                assert output[i] == pytest.helpers.setify_expected_output(expected_output[i]), f'ENVIRONMENT_SEQUENCE {i}'
+
+    @pytest.mark.psyneulink
     class TestComponentBased:
 
         def test_BeforeNCalls(self):
@@ -558,6 +678,7 @@ class TestCondition:
             expected_output = [A, A, set([A, B]), set([A, B]), set([A, B])]
             assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     class TestConvenience:
 
         def test_AtEnvironmentStateUpdateStart(self):
@@ -577,6 +698,7 @@ class TestCondition:
             expected_output = [A, B, A, A]
             assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     def test_composite_condition_multi(self):
         comp = Composition()
         A = TransferMechanism(function=Linear(slope=5.0, intercept=2.0), name='A')
@@ -611,6 +733,7 @@ class TestCondition:
         ]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     def test_AfterNCallsCombined(self):
         comp = Composition()
         A = TransferMechanism(function=Linear(slope=5.0, intercept=2.0), name='A')
@@ -638,6 +761,7 @@ class TestCondition:
         ]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     def test_AllHaveRun(self):
         comp = Composition()
         A = TransferMechanism(function=Linear(slope=5.0, intercept=2.0), name='A')
@@ -665,6 +789,7 @@ class TestCondition:
         ]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     def test_AllHaveRun_2(self):
         comp = Composition()
         A = TransferMechanism(function=Linear(slope=5.0, intercept=2.0), name='A')
@@ -690,6 +815,8 @@ class TestCondition:
         ]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+
+@pytest.mark.psyneulink
 class TestWhenFinished:
 
     @classmethod
@@ -879,6 +1006,7 @@ class TestWhenFinished:
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
 
+@pytest.mark.psyneulink
 class TestAbsolute:
     A = TransferMechanism(name='scheduler-pytests-A')
     B = TransferMechanism(name='scheduler-pytests-B')
@@ -963,6 +1091,38 @@ class TestAbsolute:
                 },
                 {TimeScale.ENVIRONMENT_STATE_UPDATE: TimeInterval(start=597)}
             ),
+            (
+                {
+                    A: TimeInterval(repeat=10, start=100, start_inclusive=False),
+                    B: TimeInterval(repeat=10, start=300),
+                    C: TimeInterval(repeat=10, start=400)
+                },
+                {TimeScale.ENVIRONMENT_STATE_UPDATE: TimeInterval(start=500)}
+            ),
+            (
+                {
+                    A: TimeInterval(repeat=10, start=100, start_inclusive=False),
+                    B: TimeInterval(repeat=10, start=300),
+                    C: TimeInterval(repeat=10, start=400)
+                },
+                {TimeScale.ENVIRONMENT_STATE_UPDATE: TimeInterval(start=500, start_inclusive=False)}
+            ),
+            (
+                {
+                    A: TimeInterval(repeat=10, start=100),
+                    B: TimeInterval(repeat=10, start=100, end=200),
+                    C: TimeInterval(repeat=10, start=400)
+                },
+                {TimeScale.ENVIRONMENT_STATE_UPDATE: TimeInterval(start=500, start_inclusive=False)}
+            ),
+            (
+                {
+                    A: TimeInterval(repeat=10, start=100),
+                    B: TimeInterval(repeat=10, start=100, end=200, end_inclusive=False),
+                    C: TimeInterval(repeat=10, start=400)
+                },
+                {TimeScale.ENVIRONMENT_STATE_UPDATE: TimeInterval(start=500)}
+            ),
         ]
     )
     def test_TimeInterval_no_dependencies(self, conditions, termination_conds):
@@ -994,6 +1154,16 @@ class TestAbsolute:
                 else:
                     assert cond.start + consideration_set_execution_abs_value in executions
 
+        # this test only runs a single ENVIRONMENT_STATE_UPDATE, so this
+        # timestamp corresponds to its last
+        final_timestamp = comp.scheduler.execution_timestamps[comp.default_execution_id][-1].absolute
+        term_cond = termination_conds[TimeScale.ENVIRONMENT_STATE_UPDATE]
+
+        if term_cond.start_inclusive:
+            assert term_cond.start - consideration_set_execution_abs_value == final_timestamp
+        else:
+            assert term_cond.start == final_timestamp
+
     @pytest.mark.parametrize(
         'repeat, unit, expected_repeat',
         [
