@@ -1,18 +1,23 @@
 import fractions
 import logging
+import networkx as nx
 import numpy as np
 import psyneulink as pnl
 import pytest
+import types
+
+import graph_scheduler
+from graph_scheduler import Scheduler
 
 from psyneulink import _unit_registry
-from psyneulink.core.components.functions.stateful.integratorfunctions import DriftDiffusionIntegrator
+from psyneulink.core.components.functions.stateful.integratorfunctions import DriftDiffusionIntegrator, SimpleIntegrator
 from psyneulink.core.components.functions.nonstateful.transferfunctions import Linear
 from psyneulink.core.components.mechanisms.processing.integratormechanism import IntegratorMechanism
 from psyneulink.core.components.mechanisms.processing.transfermechanism import TransferMechanism
 from psyneulink.core.components.projections.pathway.mappingprojection import MappingProjection
 from psyneulink.core.compositions.composition import Composition, EdgeType
 from psyneulink.core.globals.keywords import VALUE
-from psyneulink.core.scheduling.condition import AfterNCalls, AfterNPasses, AfterNEnvironmentStateUpdates, AfterPass, All, AllHaveRun, Always, Any, AtPass, BeforeNCalls, BeforePass, EveryNCalls, EveryNPasses, JustRan, TimeInterval, WhenFinished
+from psyneulink.core.scheduling.condition import AfterNCalls, AfterNPasses, AfterNEnvironmentStateUpdates, AfterPass, All, AllHaveRun, Always, Any, AtNCalls, AtPass, BeforeNCalls, BeforePass, EveryNCalls, EveryNPasses, JustRan, TimeInterval, WhenFinished
 from psyneulink.core.scheduling.time import TimeScale
 from psyneulink.library.components.mechanisms.processing.integrator.ddm import DDM
 
@@ -20,19 +25,35 @@ logger = logging.getLogger(__name__)
 
 
 class TestScheduler:
-    @classmethod
-    def setup_class(self):
-        self.orig_is_finished_flag = TransferMechanism.is_finished_flag
-        self.orig_is_finished = TransferMechanism.is_finished
-        TransferMechanism.is_finished_flag = True
-        TransferMechanism.is_finished = lambda self, context: self.is_finished_flag
+    stroop_paths = [
+        ['Color_Input', 'Color_Hidden', 'Output', 'Decision'],
+        ['Word_Input', 'Word_Hidden', 'Output', 'Decision'],
+        ['Reward']
+    ]
 
-    @classmethod
-    def teardown_class(self):
-        del TransferMechanism.is_finished_flag
-        del TransferMechanism.is_finished
-        TransferMechanism.is_finished_flag = self.orig_is_finished_flag
-        TransferMechanism.is_finished = self.orig_is_finished
+    stroop_consideration_queue = [
+        {'Color_Input', 'Word_Input', 'Reward'},
+        {'Color_Hidden', 'Word_Hidden'},
+        {'Output'},
+        {'Decision'}
+    ]
+
+    @pytest.mark.parametrize(
+        'graph, expected_consideration_queue',
+        [
+            (
+                pytest.helpers.create_graph_from_pathways(*stroop_paths),
+                stroop_consideration_queue
+            ),
+            (
+                nx.DiGraph(pytest.helpers.create_graph_from_pathways(*stroop_paths)),
+                stroop_consideration_queue
+            )
+        ]
+    )
+    def test_construction(self, graph, expected_consideration_queue):
+        sched = Scheduler(graph)
+        assert sched.consideration_queue == expected_consideration_queue
 
     def test_copy(self):
         pass
@@ -41,26 +62,26 @@ class TestScheduler:
         pass
 
     def test_create_multiple_contexts(self):
-        comp = Composition()
-        A = TransferMechanism(function=Linear(slope=5.0, intercept=2.0), name='scheduler-pytests-A')
-        comp.add_node(A)
+        graph = {'A': set()}
+        scheduler = Scheduler(graph)
 
-        comp.scheduler.get_clock(comp.scheduler.default_execution_id)._increment_time(TimeScale.ENVIRONMENT_STATE_UPDATE)
+        scheduler.get_clock(scheduler.default_execution_id)._increment_time(TimeScale.ENVIRONMENT_STATE_UPDATE)
 
         eid = 'eid'
         eid1 = 'eid1'
-        comp.scheduler._init_counts(execution_id=eid)
+        scheduler._init_counts(execution_id=eid)
 
-        assert comp.scheduler.clocks[eid].time.environment_state_update == 0
+        assert scheduler.clocks[eid].time.environment_state_update == 0
 
-        comp.scheduler.get_clock(comp.scheduler.default_execution_id)._increment_time(TimeScale.ENVIRONMENT_STATE_UPDATE)
+        scheduler.get_clock(scheduler.default_execution_id)._increment_time(TimeScale.ENVIRONMENT_STATE_UPDATE)
 
-        assert comp.scheduler.clocks[eid].time.environment_state_update == 0
+        assert scheduler.clocks[eid].time.environment_state_update == 0
 
-        comp.scheduler._init_counts(execution_id=eid1, base_execution_id=comp.scheduler.default_execution_id)
+        scheduler._init_counts(execution_id=eid1, base_execution_id=scheduler.default_execution_id)
 
-        assert comp.scheduler.clocks[eid1].time.environment_state_update == 2
+        assert scheduler.clocks[eid1].time.environment_state_update == 2
 
+    @pytest.mark.psyneulink
     def test_two_compositions_one_scheduler(self):
         comp1 = Composition()
         comp2 = Composition()
@@ -101,6 +122,7 @@ class TestScheduler:
         # pprint.pprint(output)
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     def test_one_composition_two_contexts(self):
         comp = Composition()
         A = TransferMechanism(function=Linear(slope=5.0, intercept=2.0), name='scheduler-pytests-A')
@@ -157,6 +179,7 @@ class TestScheduler:
         # pprint.pprint(output)
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     def test_change_termination_condition(self):
         D = DDM(function=DriftDiffusionIntegrator(threshold=10))
         C = Composition(pathways=[D])
@@ -192,6 +215,7 @@ class TestScheduler:
                             [np.array([2.]), np.array([1.])]]
         assert np.allclose(expected_results, np.asfarray(C.results))
 
+    @pytest.mark.psyneulink
     def test_default_condition_1(self):
         A = pnl.TransferMechanism(name='A')
         B = pnl.TransferMechanism(name='B')
@@ -205,6 +229,7 @@ class TestScheduler:
         expected_output = [B, A, B, C]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    @pytest.mark.psyneulink
     def test_default_condition_2(self):
         A = pnl.TransferMechanism(name='A')
         B = pnl.TransferMechanism(name='B')
@@ -217,7 +242,72 @@ class TestScheduler:
         expected_output = [A, B, {C, A}]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    def test_exact_time_mode(self):
+        sched = Scheduler(
+            {'A': set(), 'B': {'A'}},
+            mode=graph_scheduler.SchedulingMode.EXACT_TIME
+        )
 
+        # these cannot run at same execution set unless in EXACT_TIME
+        sched.add_condition('A', TimeInterval(start=1))
+        sched.add_condition('B', TimeInterval(start=1))
+
+        list(sched.run())
+
+        assert sched.mode == graph_scheduler.SchedulingMode.EXACT_TIME
+        assert sched.execution_list[sched.default_execution_id] == [{'A', 'B'}]
+        assert sched.execution_timestamps[sched.default_execution_id][0].absolute == 1 * graph_scheduler._unit_registry.ms
+
+    def test_run_with_new_execution_id(self):
+        sched = Scheduler({'A': set()})
+        sched.add_condition('A', graph_scheduler.AtPass(1))
+
+        output = list(sched.run(execution_id='eid'))
+
+        assert output == [set(), {'A'}]
+        assert 'eid' in sched.execution_list
+        assert sched.execution_list['eid'] == output
+
+        assert sched.get_clock('eid') == sched.get_clock(types.SimpleNamespace(default_execution_id='eid'))
+
+    def test_delete_counts(self):
+        sched = Scheduler(
+            {
+                'A': set(),
+                'B': {'A'},
+                'C': {'A'},
+                'D': {'C', 'B'}
+            }
+        )
+
+        sched.add_condition_set(
+            {
+                'A': graph_scheduler.EveryNPasses(2),
+                'B': graph_scheduler.EveryNCalls('A', 2),
+                'C': graph_scheduler.EveryNCalls('A', 3),
+                'D': graph_scheduler.AfterNCallsCombined('B', 'C', n=6)
+            }
+        )
+
+        eid_delete = 'eid'
+        eid_repeat = 'eid2'
+
+        del_run_1 = list(sched.run(execution_id=eid_delete))
+        repeat_run_1 = list(sched.run(execution_id=eid_repeat))
+
+        sched._delete_counts(eid_delete)
+
+        del_run_2 = list(sched.run(execution_id=eid_delete))
+        repeat_run_2 = list(sched.run(execution_id=eid_repeat))
+
+        assert del_run_1 == del_run_2
+        assert repeat_run_1 == repeat_run_2
+
+        assert sched.execution_list[eid_delete] == del_run_1
+        assert sched.execution_list[eid_repeat] == repeat_run_2 + repeat_run_2
+
+
+@pytest.mark.psyneulink
 class TestLinear:
 
     @classmethod
@@ -708,11 +798,114 @@ class TestLinear:
         expected_output = [A, B, C, B, C, A, B, C, B, C]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    def test_one_run_twice(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5,
+            )
+        )
+
+        c = Composition(pathways=[A])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(A, 2)}
+        stim_list = {A: [[1]]}
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mech = A
+        expected_output = [
+            np.array([1.]),
+        ]
+
+        for i in range(len(expected_output)):
+            np.testing.assert_allclose(expected_output[i], terminal_mech.get_output_values(c)[i])
+
+    def test_two_AAB(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        B = TransferMechanism(
+            name='B',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[A, B])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(B, 1)}
+        stim_list = {A: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, EveryNCalls(A, 2))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mech = B
+        expected_output = [
+            np.array([2.]),
+        ]
+
+        for i in range(len(expected_output)):
+            np.testing.assert_allclose(expected_output[i], terminal_mech.get_output_values(c)[i])
+
+    def test_two_ABB(self):
+        A = TransferMechanism(
+            name='A',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        B = IntegratorMechanism(
+            name='B',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        c = Composition(pathways=[A, B])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(B, 2)}
+        stim_list = {A: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(A, Any(AtPass(0), AfterNCalls(B, 2)))
+        sched.add_condition(B, Any(JustRan(A), JustRan(B)))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mech = B
+        expected_output = [
+            np.array([2.]),
+        ]
+
+        for i in range(len(expected_output)):
+            np.testing.assert_allclose(expected_output[i], terminal_mech.get_output_values(c)[i])
+
     ########################################
     # tests with small branching compositions
     ########################################
 
 
+@pytest.mark.psyneulink
 class TestBranching:
     @classmethod
     def setup_class(self):
@@ -1128,23 +1321,605 @@ class TestBranching:
         ]
         assert output == pytest.helpers.setify_expected_output(expected_output)
 
+    def test_three_ABAC(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
 
+        B = TransferMechanism(
+            name='B',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+        C = TransferMechanism(
+            name='C',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[[A,B],[A,C]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(C, 1)}
+        stim_list = {A: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, Any(AtNCalls(A, 1), EveryNCalls(A, 2)))
+        sched.add_condition(C, EveryNCalls(A, 2))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mechs = [B, C]
+        expected_output = [
+            [
+                np.array([1.]),
+            ],
+            [
+                np.array([2.]),
+            ],
+        ]
+
+        for m in range(len(terminal_mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], terminal_mechs[m].get_output_values(c)[i])
+
+    def test_three_ABAC_convenience(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        B = TransferMechanism(
+            name='B',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+        C = TransferMechanism(
+            name='C',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[[A,B],[A,C]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(C, 1)}
+        stim_list = {A: [[1]]}
+
+        c.scheduler.add_condition(B, Any(AtNCalls(A, 1), EveryNCalls(A, 2)))
+        c.scheduler.add_condition(C, EveryNCalls(A, 2))
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mechs = [B, C]
+        expected_output = [
+            [
+                np.array([1.]),
+            ],
+            [
+                np.array([2.]),
+            ],
+        ]
+
+        for m in range(len(terminal_mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], terminal_mechs[m].get_output_values(c)[i])
+
+    def test_three_ABACx2(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        B = TransferMechanism(
+            name='B',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+        C = TransferMechanism(
+            name='C',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[[A,B],[A,C]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(C, 2)}
+        stim_list = {A: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, Any(AtNCalls(A, 1), EveryNCalls(A, 2)))
+        sched.add_condition(C, EveryNCalls(A, 2))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mechs = [B, C]
+        expected_output = [
+            [
+                np.array([3.]),
+            ],
+            [
+                np.array([4.]),
+            ],
+        ]
+
+        for m in range(len(terminal_mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], terminal_mechs[m].get_output_values(c)[i])
+
+    def test_three_2_ABC(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        B = IntegratorMechanism(
+            name='B',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        C = TransferMechanism(
+            name='C',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[[A,C],[B,C]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(C, 1)}
+        stim_list = {A: [[1]], B: [[2]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(C, All(EveryNCalls(A, 1), EveryNCalls(B, 1)))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mechs = [C]
+        expected_output = [
+            [
+                np.array([5.]),
+            ],
+        ]
+
+        for m in range(len(terminal_mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], terminal_mechs[m].get_output_values(c)[i])
+
+    def test_three_2_ABCx2(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        B = IntegratorMechanism(
+            name='B',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        C = TransferMechanism(
+            name='C',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[[A,C],[B,C]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(C, 2)}
+        stim_list = {A: [[1]], B: [[2]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(C, All(EveryNCalls(A, 1), EveryNCalls(B, 1)))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mechs = [C]
+        expected_output = [
+            [
+                np.array([10.]),
+            ],
+        ]
+
+        for m in range(len(terminal_mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], terminal_mechs[m].get_output_values(c)[i])
+
+    def test_three_integrators(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        B = IntegratorMechanism(
+            name='B',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        C = IntegratorMechanism(
+            name='C',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        c = Composition(pathways=[[A,C],[B,C]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(C, 2)}
+        stim_list = {A: [[1]], B: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, EveryNCalls(A, 2))
+        sched.add_condition(C, Any(EveryNCalls(A, 1), EveryNCalls(B, 1)))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        mechs = [A, B, C]
+        expected_output = [
+            [
+                np.array([2.]),
+            ],
+            [
+                np.array([1.]),
+            ],
+            [
+                np.array([4.]),
+            ],
+        ]
+
+        for m in range(len(mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], mechs[m].get_output_values(c)[i])
+
+    def test_four_ABBCD(self):
+        A = TransferMechanism(
+            name='A',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        B = IntegratorMechanism(
+            name='B',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        C = IntegratorMechanism(
+            name='C',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        D = TransferMechanism(
+            name='D',
+            default_variable=[0],
+            function=Linear(slope=1.0),
+        )
+
+        c = Composition(pathways=[[A,B,D],[A,C,D]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(D, 1)}
+        stim_list = {A: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, EveryNCalls(A, 1))
+        sched.add_condition(C, EveryNCalls(A, 2))
+        sched.add_condition(D, Any(EveryNCalls(B, 3), EveryNCalls(C, 3)))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mechs = [D]
+        expected_output = [
+            [
+                np.array([4.]),
+            ],
+        ]
+
+        for m in range(len(terminal_mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], terminal_mechs[m].get_output_values(c)[i])
+
+    def test_four_integrators_mixed(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        B = IntegratorMechanism(
+            name='B',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        C = IntegratorMechanism(
+            name='C',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        D = IntegratorMechanism(
+            name='D',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        c = Composition(pathways=[[A,C],[A,D],[B,C],[B,D]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: All(AfterNCalls(C, 1), AfterNCalls(D, 1))}
+        stim_list = {A: [[1]], B: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, EveryNCalls(A, 2))
+        sched.add_condition(C, EveryNCalls(A, 1))
+        sched.add_condition(D, EveryNCalls(B, 1))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        mechs = [A, B, C, D]
+        expected_output = [
+            [
+                np.array([2.]),
+            ],
+            [
+                np.array([1.]),
+            ],
+            [
+                np.array([4.]),
+            ],
+            [
+                np.array([3.]),
+            ],
+        ]
+
+        for m in range(len(mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], mechs[m].get_output_values(c)[i])
+
+    def test_five_ABABCDE(self):
+        A = TransferMechanism(
+            name='A',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        B = TransferMechanism(
+            name='B',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        C = IntegratorMechanism(
+            name='C',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        D = TransferMechanism(
+            name='D',
+            default_variable=[0],
+            function=Linear(slope=1.0),
+        )
+
+        E = TransferMechanism(
+            name='E',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[[A,C,D],[B,C,E]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(E, 1)}
+        stim_list = {A: [[1]], B: [[2]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(C, Any(EveryNCalls(A, 1), EveryNCalls(B, 1)))
+        sched.add_condition(D, EveryNCalls(C, 1))
+        sched.add_condition(E, EveryNCalls(C, 1))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        terminal_mechs = [D, E]
+        expected_output = [
+            [
+                np.array([3.]),
+            ],
+            [
+                np.array([6.]),
+            ],
+        ]
+
+        for m in range(len(terminal_mechs)):
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], terminal_mechs[m].get_output_values(c)[i])
+
+    #
+    #   A  B
+    #   |\/|
+    #   C  D
+    #   |\/|
+    #   E  F
+    #
+    def test_six_integrators_threelayer_mixed(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        B = IntegratorMechanism(
+            name='B',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        C = IntegratorMechanism(
+            name='C',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        D = IntegratorMechanism(
+            name='D',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        E = IntegratorMechanism(
+            name='E',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        F = IntegratorMechanism(
+            name='F',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=1
+            )
+        )
+
+        c = Composition(pathways=[[A,C,E],[A,C,F],[A,D,E],[A,D,F],[B,C,E],[B,C,F],[B,D,E],[B,D,F]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: All(AfterNCalls(E, 1), AfterNCalls(F, 1))}
+        stim_list = {A: [[1]], B: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, EveryNCalls(A, 2))
+        sched.add_condition(C, EveryNCalls(A, 1))
+        sched.add_condition(D, EveryNCalls(B, 1))
+        sched.add_condition(E, EveryNCalls(C, 1))
+        sched.add_condition(F, EveryNCalls(D, 2))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        # Intermediate consideration set executions
+        #
+        #     0   1   2   3
+        #
+        # A   1   2   3   4
+        # B       1       2
+        # C   1   4   8   14
+        # D       3       9
+        # E   1   8   19  42
+        # F               23
+        #
+        expected_output = {
+            A: [
+                np.array([4.]),
+            ],
+            B: [
+                np.array([2.]),
+            ],
+            C: [
+                np.array([14.]),
+            ],
+            D: [
+                np.array([9.]),
+            ],
+            E: [
+                np.array([42.]),
+            ],
+            F: [
+                np.array([23.]),
+            ],
+        }
+
+        for m in expected_output:
+            for i in range(len(expected_output[m])):
+                np.testing.assert_allclose(expected_output[m][i], m.get_output_values(c)[i])
+
+
+@pytest.mark.psyneulink
 class TestTermination:
-
-    @classmethod
-    def setup_class(self):
-        self.orig_is_finished_flag = TransferMechanism.is_finished_flag
-        self.orig_is_finished = TransferMechanism.is_finished
-        TransferMechanism.is_finished_flag = True
-        TransferMechanism.is_finished = lambda self, context: self.is_finished_flag
-
-    @classmethod
-    def teardown_class(self):
-        del TransferMechanism.is_finished_flag
-        del TransferMechanism.is_finished
-        TransferMechanism.is_finished_flag = self.orig_is_finished_flag
-        TransferMechanism.is_finished = self.orig_is_finished
-
     def test_termination_conditions_reset(self):
         comp = Composition()
         A = TransferMechanism(function=Linear(slope=5.0, intercept=2.0), name='scheduler-pytests-A')
@@ -1206,6 +1981,57 @@ class TestTermination:
         # two executions of B
         assert output == [.75]
 
+    def test_termination_conditions_reset_execution(self):
+        A = IntegratorMechanism(
+            name='A',
+            default_variable=[0],
+            function=SimpleIntegrator(
+                rate=.5
+            )
+        )
+
+        B = TransferMechanism(
+            name='B',
+            default_variable=[0],
+            function=Linear(slope=2.0),
+        )
+
+        c = Composition(pathways=[[A,B]])
+
+        term_conds = {TimeScale.ENVIRONMENT_STATE_UPDATE: AfterNCalls(B, 2)}
+        stim_list = {A: [[1]]}
+
+        sched = pnl.Scheduler(**pytest.helpers.composition_to_scheduler_args(c))
+        sched.add_condition(B, EveryNCalls(A, 2))
+        c.scheduler = sched
+
+        c.run(
+            inputs=stim_list,
+            termination_processing=term_conds
+        )
+
+        # A should run four times
+        terminal_mech = B
+        expected_output = [
+            np.array([4.]),
+        ]
+
+        for i in range(len(expected_output)):
+            np.testing.assert_allclose(expected_output[i], terminal_mech.get_output_values(c)[i])
+
+        c.run(
+            inputs=stim_list,
+        )
+
+        # A should run an additional two times
+        terminal_mech = B
+        expected_output = [
+            np.array([6.]),
+        ]
+
+        for i in range(len(expected_output)):
+            np.testing.assert_allclose(expected_output[i], terminal_mech.get_output_values(c)[i])
+
 
 def _get_vertex_feedback_type(graph, sender_port, receiver_mech):
     # there is only one projection per pair
@@ -1223,6 +2049,7 @@ def _get_feedback_source_type(graph, sender, receiver):
         return EdgeType.NON_FEEDBACK
 
 
+@pytest.mark.psyneulink
 class TestFeedback:
 
     def test_unspecified_feedback(self):
@@ -1635,6 +2462,7 @@ class TestFeedback:
         assert np.allclose(comp.results, expected_result)
 
 
+@pytest.mark.psyneulink
 class TestAbsoluteTime:
 
     @pytest.mark.parametrize(
